@@ -1,7 +1,7 @@
 package Test::Perinci::CmdLine;
 
 our $DATE = '2016-01-22'; # DATE
-our $VERSION = '1.34'; # VERSION
+our $VERSION = '1.35'; # VERSION
 
 use 5.010001;
 use strict;
@@ -958,6 +958,7 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
                     write_text("$tempdir/infile-invalid-json", qq({}\n{\n));
                     write_text("$tempdir/infile-int", qq(1\n3\n5\n));
                     write_text("$tempdir/infile-invalid-int", qq(1\nx\n5\n));
+                    write_text("$tempdir/infile-words", qq(word1\nword2\n));
                     write_text("$tempdir/infile-invalid-words", qq(word1\nword2\nnot a word\n));
                 },
                 tests => [
@@ -991,7 +992,15 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
                     },
                     {
                         tags        => ['streaming', 'streaming-input', 'validate-streaming-input'],
-                        name        => 'stream input (json stream, error in record #2)', # test that each record is chomp-ed
+                        name        => 'stream input (simple types, words)', # test that each record is chomp-ed
+                        gen_args    => {url => '/Perinci/Examples/Stream/num_words'},
+                        inline_gen_args => {load_module=>["Perinci::Examples::Stream"]},
+                        argv        => ["$tempdir/infile-words"],
+                        stdout_like => qr/2/,
+                    },
+                    {
+                        tags        => ['streaming', 'streaming-input', 'validate-streaming-input'],
+                        name        => 'stream input (simple types, words, error in record)',
                         gen_args    => {url => '/Perinci/Examples/Stream/num_words'},
                         inline_gen_args => {load_module=>["Perinci::Examples::Stream"]},
                         argv        => ["$tempdir/infile-invalid-words"],
@@ -1446,7 +1455,7 @@ Test::Perinci::CmdLine - Common test suite for Perinci::CmdLine::{Lite,Classic,I
 
 =head1 VERSION
 
-This document describes version 1.34 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2016-01-22.
+This document describes version 1.35 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2016-01-22.
 
 =head1 FUNCTIONS
 
